@@ -40,6 +40,7 @@ def get_parser():
     assign_parser.add_argument("--no-run-tests", help="Don't run tests.", default=False, action="store_true")
     assign_parser.add_argument("--no-init-cell", help="Don't automatically generate an Otter init cell", default=False, action="store_true")
     assign_parser.add_argument("--no-check-all", help="Don't automatically add a check_all cell", default=False, action="store_true")
+    assign_parser.add_argument("--no-pdfs", help="Don't generate PDFs; overrides assignment config", default=False, action="store_true")
     # assign_parser.add_argument("--no-filter", help="Don't filter the PDF.", default=False, action="store_true")
     # assign_parser.add_argument("--instructions", help="Additional submission instructions for students")
     # assign_parser.add_argument("--jassign", default=False, action="store_true", help="Use jassign output notebook format")
@@ -47,7 +48,7 @@ def get_parser():
 
     # generate options -- COMMENTED OUT BECAUSE YOU SHOULD USE THE ASSIGNMENT METADATA FOR THIS
     # assign_parser.add_argument("--generate", default=False, action="store_true", help="Generate Gradescope autograder zipfile")
-    assign_parser.add_argument("-r", "--requirements", nargs='?', default="requirements.txt", type=str, help="Path to requirements.txt file; ignored if no generate key in assignment metadata")
+    assign_parser.add_argument("-r", "--requirements", nargs='?', default=None, help="Path to requirements.txt file; ignored if no generate key in assignment metadata")
     assign_parser.add_argument("--overwrite-requirements", default=False, action="store_true", help="Overwrite (rather than append to) default requirements for Gradescope; ignored if no REQUIREMENTS argument")
     # assign_parser.add_argument("--threshold", type=float, default=None, help="Pass/fail score threshold; use with --generate only")
     # assign_parser.add_argument("--points", type=float, default=None, help="Points possible, overrides sum of test points; use with --generate only")
@@ -93,7 +94,7 @@ def get_parser():
     generate_autograder_parser = generate_subparsers.add_parser("autograder", description="Create an autograder zip file for Gradescope")
     generate_autograder_parser.add_argument("-t", "--tests-path", nargs='?', type=str, default="./tests/", help="Path to test files")
     generate_autograder_parser.add_argument("-o", "--output-path", nargs='?', type=str, default="./", help="Path to which to write zipfile")
-    generate_autograder_parser.add_argument("-r", "--requirements", nargs='?', default="requirements.txt", type=str, help="Path to requirements.txt file; ./requirements.txt automatically checked")
+    generate_autograder_parser.add_argument("-r", "--requirements", nargs='?', default=None, help="Path to requirements.txt file; ./requirements.txt automatically checked")
     generate_autograder_parser.add_argument("--overwrite-requirements", default=False, action="store_true", help="Overwrite (rather than append to) default requirements for Gradescope; ignored if no REQUIREMENTS argument")
     generate_autograder_parser.add_argument("-l", "--lang", default="python", type=str, help="Assignment programming language; defaults to Python")
     generate_autograder_parser.add_argument("--threshold", type=float, default=None, help="Pass/fail score threshold")
@@ -149,7 +150,7 @@ def get_parser():
     grade_parser.add_argument("-f", "--files", nargs="+", help="Specify support files needed to execute code (e.g. utils, data files)")
     grade_parser.add_argument("-v", "--verbose", action="store_true", help="Flag for verbose output")
     grade_parser.add_argument("--seed", type=int, default=None, help="A random seed to be executed before each cell")
-    grade_parser.add_argument("-r", "--requirements", default="requirements.txt", type=str, help="Flag for Python requirements file path; ./requirements.txt automatically checked")
+    grade_parser.add_argument("-r", "--requirements", default=None, type=str, help="Flag for Python requirements file path; ./requirements.txt automatically checked")
     grade_parser.add_argument("--containers", type=int, help="Specify number of containers to run in parallel")
     grade_parser.add_argument("--image", default="ucbdsinfra/otter-grader", help="Custom docker image to run on")
     grade_parser.add_argument("--no-kill", action="store_true", default=False, help="Do not kill containers after grading")
