@@ -31,7 +31,7 @@ def write_autograder_dir(nb_path, output_nb_path, assignment, args):
         try:
             lang = nb["metadata"]["kernelspec"]["language"].lower()
             assignment.lang = lang
-        except IndexError:
+        except KeyError:
             warnings.warn("Could not auto-parse kernelspec from notebook; assuming Python")
             assignment.lang = "python"
 
@@ -39,9 +39,8 @@ def write_autograder_dir(nb_path, output_nb_path, assignment, args):
     tests_dir = output_dir / 'tests'
     os.makedirs(tests_dir, exist_ok=True)
 
-    requirements = assignment.requirements or args.requirements
-    if os.path.isfile(requirements):
-        shutil.copy(requirements, str(output_dir / 'requirements.txt'))
+    if assignment.requirements:
+        shutil.copy(assignment.requirements, str(output_dir / 'requirements.txt'))
 
     transformed_nb, test_files = transform_notebook(nb, assignment, args)
 
@@ -92,8 +91,7 @@ def write_student_dir(nb_name, autograder_dir, student_dir, assignment, args):
     shutil.copytree(autograder_dir, student_dir)
 
     # remove requirements from student dir if present
-    requirements = assignment.requirements or args.requirements
-    requirements = str(student_dir / os.path.split(requirements)[1])
+    requirements = str(student_dir / 'requirements.txt')
     if os.path.isfile(requirements):
         os.remove(requirements)
 
